==> nektar%2B%2B-5.4.0.tar.xz: nektar-v5.4.0/library/UnitTests/LibUtilities/LinearAlgebra/TestLowerTriangularMatrix.cpp <==
///////////////////////////////////////////////////////////////////////////////
//
// File: TestLowerTriangularMatrix.cpp
//
// For more information, please see: http://www.nektar.info
//
// The MIT License
//
// Copyright (c) 2006 Division of Applied Mathematics, Brown University (USA),
// Department of Aeronautics, Imperial College London (UK), and Scientific
// Computing and Imaging Institute, University of Utah (USA).
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//
// Description:
//
///////////////////////////////////////////////////////////////////////////////

#include <LibUtilities/LinearAlgebra/NekMatrix.hpp>
#include <boost/test/tools/floating_point_comparison.hpp>
#include <boost/test/unit_test.hpp>

namespace Nektar
{
namespace LowerTriangularMatrixUnitTests
{
typedef LowerTriangularMatrixFuncs Policy;

BOOST_AUTO_TEST_CASE(TestMatrixVectorMultiplyLower)
{
    {
        double matrix_buf[] = {1, 2, 3};
        NekMatrix<double> matrix(2, 2, matrix_buf, eLOWER_TRIANGULAR);

        double vector_buf[] = {10, 11};
        NekVector<double> vector(2, vector_buf);

        NekVector<double> result = matrix * vector;

        double expected_buf[] = {10, 53};
        NekVector<double> expected_result(2, expected_buf);

        BOOST_CHECK_EQUAL(expected_result, result);
    }
}

BOOST_AUTO_TEST_CASE(Test3x3MatrixVectorMultiplyLower)
{
    {
        // double matrix_buf[] = {1,
        //                       2, 3,
        //                       4, 5, 6};
        double matrix_buf[] = {1, 2, 4, 3, 5, 6};
        NekMatrix<double> matrix(3, 3, matrix_buf, eLOWER_TRIANGULAR);

        double vector_buf[] = {10, 11, 12};
        NekVector<double> vector(3, vector_buf);

        NekVector<double> result = matrix * vector;

        double expected_buf[] = {10, 53, 167};
        NekVector<double> expected_result(3, expected_buf);

        BOOST_CHECK_EQUAL(expected_result, result);
    }
}
} // namespace LowerTriangularMatrixUnitTests
} // namespace Nektar

==> nektar%2B%2B-5.7.0.tar.xz: nektar-v5.7.0/library/UnitTests/LibUtilities/LinearAlgebra/TestLowerTriangularMatrix.cpp <==
///////////////////////////////////////////////////////////////////////////////
//
// File: TestLowerTriangularMatrix.cpp
//
// For more information, please see: http://www.nektar.info
//
// The MIT License
//
// Copyright (c) 2006 Division of Applied Mathematics, Brown University (USA),
// Department of Aeronautics, Imperial College London (UK), and Scientific
// Computing and Imaging Institute, University of Utah (USA).
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//
// Description:
//
///////////////////////////////////////////////////////////////////////////////

#include <LibUtilities/LinearAlgebra/NekMatrix.hpp>
#include <boost/test/tools/floating_point_comparison.hpp>
#include <boost/test/unit_test.hpp>

namespace Nektar::LowerTriangularMatrixUnitTests
{
typedef LowerTriangularMatrixFuncs Policy;

BOOST_AUTO_TEST_CASE(TestMatrixVectorMultiplyLower)
{
    {
        double matrix_buf[] = {1, 2, 3};
        NekMatrix<double> matrix(2, 2, matrix_buf, eLOWER_TRIANGULAR);

        double vector_buf[] = {10, 11};
        NekVector<double> vector(2, vector_buf);

        NekVector<double> result = matrix * vector;

        double expected_buf[] = {10, 53};
        NekVector<double> expected_result(2, expected_buf);

        BOOST_CHECK_EQUAL(expected_result, result);
    }
}

BOOST_AUTO_TEST_CASE(Test3x3MatrixVectorMultiplyLower)
{
    {
        // double matrix_buf[] = {1,
        //                       2, 3,
        //                       4, 5, 6};
        double matrix_buf[] = {1, 2, 4, 3, 5, 6};
        NekMatrix<double> matrix(3, 3, matrix_buf, eLOWER_TRIANGULAR);

        double vector_buf[] = {10, 11, 12};
        NekVector<double> vector(3, vector_buf);

        NekVector<double> result = matrix * vector;

        double expected_buf[] = {10, 53, 167};
        NekVector<double> expected_result(3, expected_buf);

        BOOST_CHECK_EQUAL(expected_result, result);
    }
}
} // namespace Nektar::LowerTriangularMatrixUnitTests
